pub struct File {
pub poster: String,
pub posted_at: DateTime<Utc>,
pub subject: String,
pub groups: Vec<String>,
pub segments: Vec<Segment>,
}Expand description
Represents a complete file, consisting of segments that make up a file.
Fields
poster: StringThe poster of the file.
posted_at: DateTime<Utc>The date and time when the file was posted, in UTC.
subject: StringThe subject of the file.
groups: Vec<String>Groups that reference the file.
segments: Vec<Segment>Segments that make up the file.
Implementations
Sourceimpl File
impl File
Sourcepub fn new(
poster: impl Into<String>,
posted_at: impl Into<DateTime<Utc>>,
subject: impl Into<String>,
groups: impl IntoIterator<Item = impl Into<String>>,
segments: impl IntoIterator<Item = Segment>,
) -> Self
pub fn new( poster: impl Into<String>, posted_at: impl Into<DateTime<Utc>>, subject: impl Into<String>, groups: impl IntoIterator<Item = impl Into<String>>, segments: impl IntoIterator<Item = Segment>, ) -> Self
Creates a new File instance.
Sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
Complete name of the file with it’s extension extracted from the subject.
May return None if it fails to extract the name.
Sourcepub fn stem(&self) -> Option<&str>
pub fn stem(&self) -> Option<&str>
Base name of the file without it’s extension extracted from the File::name.
May return None if it fails to extract the stem.
Sourcepub fn extension(&self) -> Option<&str>
pub fn extension(&self) -> Option<&str>
Extension of the file extracted from the File::name.
May return None if it fails to extract the extension.
Sourcepub fn has_extension(&self, ext: impl AsRef<str>) -> bool
pub fn has_extension(&self, ext: impl AsRef<str>) -> bool
Sourcepub fn is_obfuscated(&self) -> bool
pub fn is_obfuscated(&self) -> bool